aboutsummaryrefslogtreecommitdiff
path: root/mod/embed
diff options
context:
space:
mode:
Diffstat (limited to 'mod/embed')
-rw-r--r--mod/embed/views/default/embed/upload/content.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/mod/embed/views/default/embed/upload/content.php b/mod/embed/views/default/embed/upload/content.php
index c0b7afb11..bac8e1393 100644
--- a/mod/embed/views/default/embed/upload/content.php
+++ b/mod/embed/views/default/embed/upload/content.php
@@ -12,7 +12,7 @@ if ($upload_sections) {
$options[$id] = $info['name'];
}
- $input = elgg_view('input/pulldown', array(
+ $input = elgg_view('input/dropdown', array(
'name' => 'download_section',
'options_values' => $options,
'internalid' => 'embed_upload',
@@ -32,7 +32,7 @@ if ($upload_sections) {
<script type="text/javascript">
$(document).ready(function() {
// change for pulldown
$('#embed_upload').change(function() {
var upload_section = $(this).val();
var url = '<?php echo elgg_get_site_url(); ?>pg/embed/embed?active_section=upload&active_upload_section=' + upload_section;
@@ -32,7 +32,7 @@ if ($upload_sections) {
<script type="text/javascript">
$(document).ready(function() {
- // change for pulldown
+ // change for dropdown
$('#embed_upload').change(function() {
var upload_section = $(this).val();